=======
vis_cpu
=======
.. image:: https://github.com/hera-team/vis_cpu/workflows/Tests/badge.svg
    :target: https://github.com/hera-team/vis_cpu
.. image:: https://badge.fury.io/py/vis_cpu.svg
    :target: https://badge.fury.io/py/vis_cpu
.. image:: https://codecov.io/gh/hera-team/vis_cpu/branch/main/graph/badge.svg
    :target: https://codecov.io/gh/hera-team/vis_cpu
.. image:: https://img.shields.io/pypi/pyversions/vis_cpu.svg
    :target: https://pypi.org/project/vis_cpu/
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black


Fast visibility simulator with interface to CPU and GPU


Description
===========

A longer description of your project goes here...

Installation
============
Merely do ``pip install vis_cpu``. If you want to use the GPU functions, install
with ``pip install vis_cpu.[gpu]``.

Read the Docs
=============
https://vis-cpu.readthedocs.io/en/latest/
